@@ -9,7 +9,7 @@ use Data::Dumper;
 use Sparrow::Constants;
 use Sparrow::Commands::Plugin;
 use Sparrow::Commands::Project;
-use Sparrow::Commands::CheckPoint;
+use Sparrow::Commands::Task;
 use Sparrow::Misc;
 
 1;
